------------------------------------------------------------------------------
--	FILE:	 TinyEarth.lua
--  by totalslacker
------------------------------------------------------------------------------

include "MapEnums"
include "MapUtilities"
include "MountainsCliffs"
include "RiversLakes"
include "FeatureGenerator"
include "TerrainGenerator"
include "NaturalWonderGenerator"
include "ResourceGenerator"
include "AssignStartingPlots"

local mapName = MapConfiguration.GetValue("MapName")
print("Loading "..tostring(mapName).." script")

local g_iW = 44
local g_iH = 26
local g_iFlags = {};
local g_continentsFrac = nil;

------------------------------------------------------------------------------
-- The application side will call GetMapScriptInfo directly to request
-- information about the map script.
-------------------------------------------------------------------------------
function GetMapInitData(worldSize)
	return {
		Width = g_iW,
		Height = g_iH,
		WrapX = true,
		WrapY = false,
	};      
end

-------------------------------------------------------------------------------
function GenerateMap()
	print("Calling Map Generator");
	-- Everything has been moved to the modded AssignStartingPlots in the "override" folder, search for "YnAMP" string in that file
	GenerateImportedMap(GetMap(), GetCiv6DataToConvert(), GetNaturalWonders(), g_iW, g_iH)
	
	-- Handle Nile delta flow direction (North)
	-- for x = 56, 60 do
		-- for y = 33, 37 do
			-- local plot = Map.GetPlot(x,y)
			-- if plot then
				-- MakeRiverFlowToNorth(plot)			
			-- end
		-- end
	-- end
	
	-- Handle source of the Nile flow direction	
	-- for x = 60, 61 do
		-- for y = 22, 23 do
			-- local plot = Map.GetPlot(x,y)
			-- if plot then
				-- MakeRiverFlowToNorth(plot)			
			-- end
		-- end
	-- end
	
end

function GetNaturalWonders()
	--Deprecated function, returns nothing
	local NaturalWonders = {}	
	return NaturalWonders
end

function GetCiv6DataToConvert()
	-- Map data was exported from Civ6 WB, cliffs are included in MapToConvert
	return {}
end

function GetMap()

	local MapToConvert = {}
	for i = 0, g_iW - 1, 1 do
		MapToConvert[i] = {}
	end
	
	-- Map Data (from Civ6 WB)
	-- MapToConvert[x][y] = {civ6TerrainType, civ6FeatureTypes, civ6ContinentType, {{IsNEOfRiver, flow}, {IsWOfRiver, flow}, {IsNWOfRiver, flow}}, {Civ6ResourceType, num}, {IsNEOfCliff, IsWOfCliff, IsNWOfCliff} }
MapToConvert[43][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[7][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[6][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[5][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[3][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[2][0]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][0]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[31][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[27][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[24][1]={"TERRAIN_TUNDRA",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][1]={"TERRAIN_TUNDRA","FEATURE_TORRES_DEL_PAINE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][1]={"TERRAIN_TUNDRA","FEATURE_TORRES_DEL_PAINE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][1]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[18][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[11][1]={"TERRAIN_GRASS","FEATURE_PIOPIOTAHI","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][1]={"TERRAIN_GRASS_HILLS","FEATURE_PIOPIOTAHI","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[6][1]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,1}}
MapToConvert[5][1]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{1,0,0}}
MapToConvert[4][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[3][1]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][1]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][1]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][1]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[43][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][2]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][2]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CATTLE",1},{0,0,0}}
MapToConvert[30][2]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[28][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][2]={"TERRAIN_DESERT",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][2]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[21][2]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][2]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[18][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][2]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][2]={"TERRAIN_GRASS_HILLS","FEATURE_PIOPIOTAHI","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[9][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][2]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][2]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[6][2]={"TERRAIN_DESERT",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][2]={"TERRAIN_DESERT",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SILVER",1},{1,0,0}}
MapToConvert[4][2]={"TERRAIN_DESERT",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[3][2]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][2]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][2]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[0][2]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][3]={"TERRAIN_GRASS_MOUNTAIN","FEATURE_VOLCANO",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][3]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][3]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[33][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][3]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[31][3]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{1,5},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[30][3]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{1,5},{0,-1},{1,4}},{"RESOURCE_DIAMONDS",1},{0,0,0}}
MapToConvert[29][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[28][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[22][3]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][3]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][3]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][3]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][3]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ZEALANDIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][3]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][3]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[6][3]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][3]={"TERRAIN_DESERT",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[4][3]={"TERRAIN_DESERT_HILLS","FEATURE_ULURU","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][3]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[2][3]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][3]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[0][3]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[43][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][4]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][4]={"TERRAIN_PLAINS_HILLS","FEATURE_TSINGY","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[33][4]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][4]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[31][4]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[30][4]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,1,0}}
MapToConvert[28][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[23][4]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[22][4]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][4]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][4]={"TERRAIN_DESERT",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{1,4}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[19][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[18][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[12][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[10][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][4]={"TERRAIN_COAST","FEATURE_BARRIER_REEF",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][4]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[6][4]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][4]={"TERRAIN_PLAINS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][4]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DIAMONDS",1},{0,0,0}}
MapToConvert[3][4]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[2][4]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[1][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][4]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[42][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[35][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][5]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][5]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_CATTLE",1},{0,0,0}}
MapToConvert[31][5]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DIAMONDS",1},{0,0,0}}
MapToConvert[30][5]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[28][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[24][5]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][5]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SUGAR",1},{0,0,0}}
MapToConvert[22][5]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_SOUTH_AMERICA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_TOBACCO",1},{0,0,0}}
MapToConvert[21][5]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][5]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][5]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[18][5]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[16][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][5]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][5]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[8][5]={"TERRAIN_COAST","FEATURE_BARRIER_REEF",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][5]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TURTLES",1},{0,0,0}}
MapToConvert[6][5]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[5][5]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[4][5]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AUSTRALIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][5]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{1,1,1}}
MapToConvert[2][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[1][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[0][5]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][6]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[42][6]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TURTLES",1},{0,0,0}}
MapToConvert[41][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[35][6]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][6]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][6]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][6]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{1,2},{0,-1},{1,1}},{"RESOURCE_IVORY",1},{0,0,0}}
MapToConvert[31][6]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][6]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CATTLE",1},{1,0,0}}
MapToConvert[29][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,1,0}}
MapToConvert[28][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][6]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DYES",1},{0,0,0}}
MapToConvert[24][6]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][6]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[22][6]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][6]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_COCOA",1},{0,0,0}}
MapToConvert[20][6]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][6]={"TERRAIN_DESERT_MOUNTAIN","FEATURE_VOLCANO",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][6]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][6]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][6]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TURTLES",1},{0,0,0}}
MapToConvert[12][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][6]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][6]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[8][6]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][6]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[3][6]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[2][6]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[1][6]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][6]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][7]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][7]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[41][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][7]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SPICES",1},{0,0,0}}
MapToConvert[38][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][7]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_INCENSE",1},{0,0,0}}
MapToConvert[34][7]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][7]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][7]={"TERRAIN_GRASS_MOUNTAIN","FEATURE_KILIMANJARO","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][7]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][7]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[27][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][7]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][7]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[22][7]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[21][7]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{1,2},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[20][7]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_COFFEE",1},{0,0,0}}
MapToConvert[19][7]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][7]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[16][7]={"TERRAIN_OCEAN","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TURTLES",1},{0,0,0}}
MapToConvert[15][7]={"TERRAIN_COAST","FEATURE_GALAPAGOS",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][7]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[12][7]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][7]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[10][7]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][7]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[8][7]={"TERRAIN_GRASS_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][7]={"TERRAIN_GRASS_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][7]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[5][7]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SPICES",1},{0,0,0}}
MapToConvert[4][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][7]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[0][7]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][8]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[41][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][8]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[39][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][8]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][8]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][8]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COFFEE",1},{0,0,0}}
MapToConvert[33][8]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_AFRICA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[32][8]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][8]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{1,5},{1,0},{0,-1}},{"RESOURCE_COFFEE",1},{0,0,0}}
MapToConvert[30][8]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[29][8]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_AFRICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][8]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IVORY",1},{0,0,0}}
MapToConvert[27][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[26][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[24][8]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][8]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][8]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{1,2},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[21][8]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[20][8]={"TERRAIN_PLAINS",-1,"CONTINENT_SOUTH_AMERICA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[19][8]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[17][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][8]={"TERRAIN_COAST","FEATURE_GALAPAGOS",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][8]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[11][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][8]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][8]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_BANANAS",1},{0,0,0}}
MapToConvert[7][8]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[4][8]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_BANANAS",1},{0,0,0}}
MapToConvert[3][8]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][8]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][8]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[43][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[42][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[39][9]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SPICES",1},{0,0,0}}
MapToConvert[38][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[35][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][9]={"TERRAIN_DESERT_MOUNTAIN","FEATURE_VOLCANO","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][9]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{1,5},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][9]={"TERRAIN_PLAINS","FEATURE_MARSH","CONTINENT_AFRICA",{{0,-1},{1,0},{1,1}},{"RESOURCE_CATTLE",1},{0,0,0}}
MapToConvert[31][9]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{1,5},{0,-1},{0,-1}},{"RESOURCE_IVORY",1},{0,0,0}}
MapToConvert[30][9]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[29][9]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[28][9]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DIAMONDS",1},{0,0,0}}
MapToConvert[27][9]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][9]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[22][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][9]={"TERRAIN_PLAINS","FEATURE_MARSH","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[20][9]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[19][9]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[16][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][9]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][9]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[6][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][9]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][9]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][9]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,1,0}}
MapToConvert[1][9]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][9]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[42][10]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][10]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][10]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][10]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][10]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COFFEE",1},{0,0,0}}
MapToConvert[35][10]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[34][10]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][10]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[32][10]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_GYPSUM",1},{0,0,0}}
MapToConvert[31][10]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][10]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][10]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][10]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{1,5},{1,0},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[27][10]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[26][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[25][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][10]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_SOUTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[21][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[20][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][10]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_JADE",1},{0,0,0}}
MapToConvert[18][10]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][10]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[15][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][10]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][10]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][10]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][10]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[2][10]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][10]={"TERRAIN_GRASS",-1,"CONTINENT_ASIA",{{1,2},{1,3},{0,-1}},{"RESOURCE_IVORY",1},{0,0,0}}
MapToConvert[0][10]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[43][11]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{1,3},{1,4}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[42][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[40][11]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[39][11]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[37][11]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_INCENSE",1},{0,0,0}}
MapToConvert[36][11]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][11]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SHEEP",1},{0,0,0}}
MapToConvert[34][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[33][11]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{1,5},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[32][11]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_AFRICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][11]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[30][11]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[29][11]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[28][11]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[27][11]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SALT",1},{0,0,0}}
MapToConvert[26][11]={"TERRAIN_DESERT",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][11]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[22][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][11]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][11]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{1,1}},{"RESOURCE_COCOA",1},{0,0,0}}
MapToConvert[17][11]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][11]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TOBACCO",1},{0,0,0}}
MapToConvert[15][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][11]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][11]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[4][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[2][11]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{1,0,0}}
MapToConvert[1][11]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_BANANAS",1},{0,1,0}}
MapToConvert[0][11]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][12]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_JADE",1},{0,0,0}}
MapToConvert[42][12]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][12]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{1,0},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,1}}
MapToConvert[40][12]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[39][12]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][12]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[36][12]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[35][12]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_INCENSE",1},{0,0,0}}
MapToConvert[34][12]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{1,0,0}}
MapToConvert[33][12]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_AFRICA",{{1,5},{0,-1},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[32][12]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_AFRICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][12]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][12]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[29][12]={"TERRAIN_PLAINS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][12]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][12]={"TERRAIN_DESERT_MOUNTAIN",-1,"CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{1,4}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[25][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][12]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[22][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][12]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SUGAR",1},{0,0,0}}
MapToConvert[20][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[19][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[18][12]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[17][12]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[16][12]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[15][12]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[13][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][12]={"TERRAIN_OCEAN","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[9][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][12]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][12]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[5][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][12]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][12]={"TERRAIN_COAST","FEATURE_HA_LONG_BAY",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][12]={"TERRAIN_COAST","FEATURE_HA_LONG_BAY",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][12]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[0][12]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{1,3},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[43][13]={"TERRAIN_GRASS_MOUNTAIN",-1,"CONTINENT_ASIA",{{1,2},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][13]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{1,3},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[41][13]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{1,3},{1,1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[40][13]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[39][13]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[38][13]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[37][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][13]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_PEARLS",1},{0,0,0}}
MapToConvert[35][13]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[34][13]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_HORSES",1},{0,0,0}}
MapToConvert[33][13]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[32][13]={"TERRAIN_COAST",-1,-1,{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[29][13]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_EUROPE",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[28][13]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[27][13]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_AFRICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][13]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TURTLES",1},{0,0,0}}
MapToConvert[21][13]={"TERRAIN_COAST","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[20][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[18][13]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][13]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[16][13]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[15][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][13]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[13][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][13]={"TERRAIN_OCEAN","FEATURE_REEF",-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[10][13]={"TERRAIN_PLAINS_HILLS","FEATURE_JUNGLE","CONTINENT_OCEANIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SUGAR",1},{0,0,0}}
MapToConvert[9][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][13]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[6][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][13]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[4][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][13]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][13]={"TERRAIN_GRASS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][13]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_TEA",1},{0,0,0}}
MapToConvert[0][13]={"TERRAIN_GRASS_HILLS","FEATURE_JUNGLE","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[43][14]={"TERRAIN_GRASS_MOUNTAIN",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[42][14]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[41][14]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[40][14]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{"RESOURCE_DYES",1},{0,0,0}}
MapToConvert[39][14]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_COTTON",1},{0,0,0}}
MapToConvert[38][14]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[37][14]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][14]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[35][14]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[34][14]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[31][14]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WINE",1},{0,0,0}}
MapToConvert[30][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[28][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[26][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][14]={"TERRAIN_PLAINS","FEATURE_JUNGLE","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][14]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][14]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_COTTON",1},{0,0,0}}
MapToConvert[18][14]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[17][14]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][14]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[15][14]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,1,0}}
MapToConvert[13][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[12][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[9][14]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][14]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SILK",1},{0,0,0}}
MapToConvert[6][14]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[4][14]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[3][14]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][14]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[1][14]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{1,0},{1,1}},{"RESOURCE_JADE",1},{0,0,0}}
MapToConvert[0][14]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[43][15]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[42][15]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_ASIA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[41][15]={"TERRAIN_TUNDRA_MOUNTAIN","FEATURE_EVEREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][15]={"TERRAIN_TUNDRA_MOUNTAIN","FEATURE_EVEREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][15]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[38][15]={"TERRAIN_DESERT_MOUNTAIN",-1,"CONTINENT_ASIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[37][15]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_GYPSUM",1},{0,0,0}}
MapToConvert[36][15]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[35][15]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[34][15]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_COTTON",1},{0,0,0}}
MapToConvert[33][15]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DYES",1},{0,0,0}}
MapToConvert[32][15]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[30][15]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[29][15]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[27][15]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[26][15]={"TERRAIN_PLAINS",-1,"CONTINENT_EUROPE",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[24][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][15]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][15]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[18][15]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][15]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[16][15]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[15][15]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[14][15]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[12][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][15]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[7][15]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][15]={"TERRAIN_GRASS_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][15]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[3][15]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][15]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[1][15]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_ASIA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_RICE",1},{0,0,0}}
MapToConvert[0][15]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_SILK",1},{0,0,0}}
MapToConvert[43][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[42][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[41][16]={"TERRAIN_TUNDRA_MOUNTAIN","FEATURE_EVEREST","CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[40][16]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[39][16]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[38][16]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[37][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][16]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][16]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[34][16]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][16]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,3},{1,4}},{"RESOURCE_MARBLE",1},{0,0,0}}
MapToConvert[31][16]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,3},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[30][16]={"TERRAIN_GRASS_HILLS",-1,"CONTINENT_EUROPE",{{1,5},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][16]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[27][16]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[26][16]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[21][16]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[20][16]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,2},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[19][16]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[18][16]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{1,4}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[16][16]={"TERRAIN_DESERT_HILLS","FEATURE_DELICATE_ARCH","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][16]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][16]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][16]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[6][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[5][16]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_JADE",1},{0,1,1}}
MapToConvert[4][16]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][16]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[2][16]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[1][16]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][16]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{1,2},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[43][17]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][17]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_JADE",1},{0,0,0}}
MapToConvert[41][17]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][17]={"TERRAIN_DESERT","FEATURE_FLOODPLAINS","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][17]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{1,5},{1,3},{1,4}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[38][17]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_COTTON",1},{0,0,0}}
MapToConvert[37][17]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[36][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SHEEP",1},{0,0,0}}
MapToConvert[34][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[33][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][17]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,2},{1,3},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[30][17]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_EUROPE",{{0,-1},{1,3},{1,4}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[29][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][17]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WINE",1},{0,0,0}}
MapToConvert[27][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[26][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][17]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[24][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][17]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[21][17]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{1,4}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[19][17]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[18][17]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[17][17]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][17]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][17]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[14][17]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][17]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[12][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][17]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][17]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[7][17]={"TERRAIN_GRASS_MOUNTAIN","FEATURE_VOLCANO",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[5][17]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{1,0,0}}
MapToConvert[4][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[3][17]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[2][17]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][17]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][17]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[43][18]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[42][18]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][18]={"TERRAIN_PLAINS_HILLS",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[40][18]={"TERRAIN_DESERT_MOUNTAIN",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[39][18]={"TERRAIN_DESERT_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[38][18]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][18]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[36][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,1}} -- Lake
MapToConvert[35][18]={"TERRAIN_GRASS_MOUNTAIN",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{1,0,0}} -- Lake
MapToConvert[33][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,1}} -- Lake
MapToConvert[32][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[31][18]={"TERRAIN_GRASS",-1,"CONTINENT_EUROPE",{{1,2},{1,3},{0,-1}},{"RESOURCE_HORSES",1},{0,0,0}}
MapToConvert[30][18]={"TERRAIN_GRASS_MOUNTAIN","FEATURE_MATTERHORN","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][18]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[28][18]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,0},{1,1}},{"RESOURCE_NITER",1},{0,0,0}}
MapToConvert[27][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{1,0,0}}
MapToConvert[26][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[25][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[22][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DEER",1},{0,0,0}}
MapToConvert[20][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}} -- Lake
MapToConvert[19][18]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][18]={"TERRAIN_PLAINS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[16][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[14][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[13][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[12][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][18]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][18]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[4][18]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[3][18]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][18]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[1][18]={"TERRAIN_GRASS_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_HORSES",1},{0,0,0}}
MapToConvert[0][18]={"TERRAIN_GRASS_HILLS",-1,"CONTINENT_ASIA",{{1,2},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[43][19]={"TERRAIN_GRASS_HILLS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_SHEEP",1},{0,0,0}}
MapToConvert[42][19]={"TERRAIN_PLAINS_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][19]={"TERRAIN_PLAINS_MOUNTAIN",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][19]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[39][19]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][19]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_HORSES",1},{0,0,0}}
MapToConvert[37][19]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[36][19]={"TERRAIN_DESERT",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[35][19]={"TERRAIN_PLAINS",-1,"CONTINENT_EUROPE",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][19]={"TERRAIN_PLAINS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_HORSES",1},{0,0,0}}
MapToConvert[33][19]={"TERRAIN_PLAINS",-1,"CONTINENT_EUROPE",{{0,-1},{1,3},{1,1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[32][19]={"TERRAIN_PLAINS",-1,"CONTINENT_EUROPE",{{0,-1},{1,3},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[31][19]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[30][19]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[29][19]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,5},{1,0},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[28][19]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,5},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][19]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[26][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,1,0}}
MapToConvert[25][19]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][19]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[22][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][19]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[20][19]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[19][19]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COPPER",1},{0,0,0}}
MapToConvert[18][19]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][19]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{1,1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[16][19]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{1,1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[15][19]={"TERRAIN_SNOW_MOUNTAIN","FEATURE_VOLCANO",-1,{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[12][19]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][19]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][19]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][19]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][19]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[5][19]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][19]={"TERRAIN_PLAINS",-1,"CONTINENT_SIBERIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[3][19]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][19]={"TERRAIN_PLAINS",-1,"CONTINENT_ASIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][19]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_ASIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][19]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}} -- Lake
MapToConvert[43][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][20]={"TERRAIN_PLAINS",-1,"CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][20]={"TERRAIN_PLAINS",-1,"CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[38][20]={"TERRAIN_PLAINS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHEAT",1},{0,0,0}}
MapToConvert[37][20]={"TERRAIN_PLAINS",-1,"CONTINENT_SIBERIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[36][20]={"TERRAIN_PLAINS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,3},{1,4}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[35][20]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,5},{1,3},{1,4}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[34][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,3},{1,4}},{-1,1},{0,0,0}}
MapToConvert[33][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[30][20]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][20]={"TERRAIN_GRASS","FEATURE_MARSH","CONTINENT_EUROPE",{{1,5},{1,0},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[28][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][20]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][20]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[21][20]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[20][20]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][20]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][20]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[17][20]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][20]={"TERRAIN_SNOW_MOUNTAIN",-1,-1,{{1,5},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_SILVER",1},{0,0,0}}
MapToConvert[14][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[13][20]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[12][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][20]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][20]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[8][20]={"TERRAIN_TUNDRA_MOUNTAIN","FEATURE_VOLCANO","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][20]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[5][20]={"TERRAIN_TUNDRA_MOUNTAIN",-1,-1,{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[4][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[3][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,2},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[2][20]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[1][20]={"TERRAIN_TUNDRA_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][20]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{1,0},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[43][21]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{1,5},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[41][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[40][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[39][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[38][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[37][21]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[36][21]={"TERRAIN_TUNDRA_MOUNTAIN",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,-1},{0,-1}},{"RESOURCE_DYES",1},{0,0,0}}
MapToConvert[33][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[32][21]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_AMBER",1},{0,0,0}}
MapToConvert[31][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}} -- Lake
MapToConvert[30][21]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][21]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{1,0,1}}
MapToConvert[26][21]={"TERRAIN_PLAINS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_STONE",1},{0,0,0}}
MapToConvert[25][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[24][21]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][21]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[21][21]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[18][21]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][21]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_DIAMONDS",1},{0,0,0}}
MapToConvert[16][21]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[15][21]={"TERRAIN_SNOW_MOUNTAIN",-1,"CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[13][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[12][21]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_NORTH_AMERICA",{{0,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[11][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[10][21]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][21]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[8][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][21]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][21]={"TERRAIN_TUNDRA_MOUNTAIN",-1,-1,{{1,2},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[3][21]={"TERRAIN_TUNDRA_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[2][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[1][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][21]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][22]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[37][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[36][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[35][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][22]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_EUROPE",{{0,-1},{1,0},{1,1}},{"RESOURCE_SALT",1},{0,0,0}}
MapToConvert[33][22]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_AMBER",1},{0,0,0}} -- Lake
MapToConvert[31][22]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,5},{0,-1},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[30][22]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,4}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[29][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_AMBER",1},{0,1,0}}
MapToConvert[28][22]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][22]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[26][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][22]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][22]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][22]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][22]={"TERRAIN_SNOW_MOUNTAIN",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][22]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[19][22]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][22]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][22]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][22]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][22]={"TERRAIN_SNOW_MOUNTAIN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][22]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][22]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[11][22]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][22]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][22]={"TERRAIN_SNOW",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][22]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{1,0},{0,1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[7][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,3},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][22]={"TERRAIN_TUNDRA_MOUNTAIN",-1,-1,{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{1,5},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[3][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[2][22]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[1][22]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][22]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][23]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{0,-1},{1,0},{1,1}},{-1,1},{0,0,0}}
MapToConvert[42][23]={"TERRAIN_TUNDRA",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[41][23]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[39][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[38][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][23]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][23]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_SIBERIA",{{1,5},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][23]={"TERRAIN_TUNDRA",-1,"CONTINENT_EUROPE",{{0,-1},{1,0},{0,-1}},{"RESOURCE_COAL",1},{0,0,0}}
MapToConvert[34][23]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_EUROPE",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][23]={"TERRAIN_TUNDRA","FEATURE_MARSH","CONTINENT_EUROPE",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][23]={"TERRAIN_TUNDRA","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[31][23]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][23]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_IRON",1},{0,0,0}}
MapToConvert[29][23]={"TERRAIN_GRASS_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{1,4}},{-1,1},{0,0,0}}
MapToConvert[28][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[27][23]={"TERRAIN_GRASS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][23]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,1,0}}
MapToConvert[24][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][23]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][23]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_WHALES",1},{0,0,0}}
MapToConvert[21][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{1,0,0}}
MapToConvert[20][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,1}}
MapToConvert[19][23]={"TERRAIN_SNOW",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][23]={"TERRAIN_SNOW",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_MERCURY",1},{0,0,0}}
MapToConvert[17][23]={"TERRAIN_SNOW",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][23]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][23]={"TERRAIN_SNOW",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[13][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[11][23]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][23]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][23]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[7][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{1,2},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{1,1}},{-1,1},{0,0,0}}
MapToConvert[4][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][23]={"TERRAIN_SNOW",-1,"CONTINENT_SIBERIA",{{1,5},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][23]={"TERRAIN_SNOW",-1,"CONTINENT_SIBERIA",{{0,-1},{1,0},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][23]={"TERRAIN_SNOW",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][23]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_SIBERIA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_ALUMINUM",1},{0,0,0}}
MapToConvert[43][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[42][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][24]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][24]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][24]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[32][24]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][24]={"TERRAIN_TUNDRA_MOUNTAIN",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[30][24]={"TERRAIN_TUNDRA_HILLS","FEATURE_FOREST","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[28][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[27][24]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,1}}
MapToConvert[25][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][24]={"TERRAIN_TUNDRA_HILLS",-1,"CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[22][24]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][24]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[20][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[19][24]={"TERRAIN_SNOW",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[16][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][24]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][24]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][24]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[8][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[5][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][24]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][24]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][24]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FISH",1},{0,0,0}}
MapToConvert[0][24]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[43][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[42][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[41][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[40][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[39][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[38][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[37][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[36][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[35][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[34][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[33][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[32][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[31][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[30][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[29][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[28][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_OIL",1},{0,0,0}}
MapToConvert[27][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[26][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[25][25]={"TERRAIN_SNOW_HILLS","FEATURE_EYJAFJALLAJOKULL","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[24][25]={"TERRAIN_SNOW_HILLS","FEATURE_EYJAFJALLAJOKULL","CONTINENT_EUROPE",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[23][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{"RESOURCE_CRABS",1},{0,0,0}}
MapToConvert[22][25]={"TERRAIN_COAST",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[21][25]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{-1,1},{0,1,0}}
MapToConvert[20][25]={"TERRAIN_TUNDRA",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_FURS",1},{0,0,0}}
MapToConvert[19][25]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[18][25]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[17][25]={"TERRAIN_SNOW_HILLS",-1,"CONTINENT_NORTH_AMERICA",{{0,-1},{0,-1},{0,-1}},{"RESOURCE_URANIUM",1},{0,0,0}}
MapToConvert[16][25]={"TERRAIN_COAST","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[15][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[14][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[13][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[12][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[11][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[10][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[9][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[8][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[7][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[6][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[5][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[4][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[3][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[2][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[1][25]={"TERRAIN_OCEAN",-1,-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}
MapToConvert[0][25]={"TERRAIN_OCEAN","FEATURE_ICE",-1,{{0,-1},{0,-1},{0,-1}},{-1,1},{0,0,0}}

	return MapToConvert
end